| single_asip | R Documentation |
Calculates the minimum required sample size for a single acceptance sampling inspection plan under a time-truncated life test using the producer's risk condition Pa <= be.
single_asip(p, a, b, be = 0.25, c = 0)
p |
User-defined probability of failure before the termination time. It must lie between 0 and 1. |
a |
Termination ratio, defined as a = t/theta0. It must be a positive numeric value. |
b |
Quality ratio, defined as b = theta/theta0. It must be a positive numeric value. |
be |
Producer's risk. It must be a value between 0 and 1. |
c |
Acceptance number. It must be a non-negative integer. |
The probability p is user-defined. Therefore, no particular lifetime distribution is embedded in this function.
A data frame containing a, b, p, be, c, required sample size n, and probability of acceptance Pa.
# Example 1: User-defined failure probabilities
p <- c(0.05, 0.10, 0.15, 0.20)
single_asip(
p = p,
a = c(0.5, 1, 1.5, 2),
b = 1,
be = 0.25,
c = 0
)
# Example 2: Failure probabilities obtained from
# a Burr Type X lifetime distribution
al <- 0.5
b <- 1
a <- c(0.4, 0.6, 0.8, 1, 1.5, 2, 2.5, 3)
h <- sqrt(
-log(
1 - (1/2)^(1/al)
)
)
p <- (1 - exp(-(a * h / b)^2))^al
single_asip(
p = p,
a = a,
b = b,
be = 0.25,
c = 6
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.